@@ -1,4 +1,4 @@
-use core_foundation_sys::base::{OSStatus, CFTypeID};
+use core_foundation_sys::base::{OSStatus, CFTypeID, CFTypeRef};
 
 use base::{SecCertificateRef, SecKeyRef, SecIdentityRef};
 
@@ -10,4 +10,9 @@ extern "C" {
     pub fn SecIdentityCopyPrivateKey(identity: SecIdentityRef,
                                      key_ref: *mut SecKeyRef)
                                      -> OSStatus;
+    #[cfg(target_os = "macos")]
+    pub fn SecIdentityCreateWithCertificate(keychain_or_Array: CFTypeRef,
+                                            certificate_ref: SecCertificateRef,
+                                            identity_ref: *mut SecIdentityRef)
+                                            -> OSStatus;
 }
