@@ -1,5 +1,5 @@
-#![doc(html_root_url = "https://sfackler.github.io/rust-security-framework/doc/v0.1.14")]
-#![allow(non_upper_case_globals)]
+#![doc(html_root_url = "https://sfackler.github.io/rust-security-framework/doc/v0.2")]
+#![allow(bad_style)]
 
 extern crate core_foundation_sys;
 extern crate libc;
